#include <stdint.h>

typedef enum {
    UNWF_RIP=0,
    UNWF_RSP=1,
    UNWF_RBP=2,
    UNWF_RBX=3,

    UNWF_ERROR=7
} unwind_flags_t;

typedef struct {
    uint8_t flags;
    uintptr_t rip, rsp, rbp, rbx;
} unwind_context_t;

typedef uintptr_t (*deref_func_t)(uintptr_t);

typedef unwind_context_t (*_fde_func_t)(unwind_context_t, uintptr_t);
typedef unwind_context_t (*_fde_func_with_deref_t)(
        unwind_context_t,
        uintptr_t,
        deref_func_t);

#include <assert.h>



unwind_context_t _eh_elf(unwind_context_t ctx, uintptr_t pc) {
	unwind_context_t out_ctx;
	switch(pc) {
		case 0x35c0 ... 0x35c1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x35c2 ... 0x35c3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x35c4 ... 0x35c5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x35c6 ... 0x35c7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x35c8 ... 0x35c8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x35c9 ... 0x35c9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x35ca ... 0x35d2:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x35d3 ... 0x39a6:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x39a7 ... 0x39ad:
			out_ctx.rsp = ctx.rsp + (152);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x39ae ... 0x39cf:
			out_ctx.rsp = ctx.rsp + (160);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x39d0 ... 0x39d0:
			out_ctx.rsp = ctx.rsp + (152);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x39d1 ... 0x3b5d:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x3b5e ... 0x3b6d:
			out_ctx.rsp = ctx.rsp + (152);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x3b6e ... 0x3b8b:
			out_ctx.rsp = ctx.rsp + (160);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x3b8c ... 0x443d:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x443e ... 0x443e:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x443f ... 0x443f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x4440 ... 0x4441:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x4442 ... 0x4443:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x4444 ... 0x4445:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x4446 ... 0x4447:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x4448 ... 0x4448:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x4449 ... 0x516f:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5170 ... 0x517e:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x517f ... 0x5183:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5184 ... 0x518a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x518b ... 0x518c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x518d ... 0x5190:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5191 ... 0x519b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x519c ... 0x5278:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5279 ... 0x5279:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x527a ... 0x527b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x527c ... 0x527d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x527e ... 0x527f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5280 ... 0x5281:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5282 ... 0x5287:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5288 ... 0x544f:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5450 ... 0x5453:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5454 ... 0x5496:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5497 ... 0x549f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54a0 ... 0x54cf:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54d0 ... 0x54d1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54d2 ... 0x54d3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54d4 ... 0x54d7:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54d8 ... 0x54d9:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54da ... 0x54da:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x54db ... 0x54db:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x54dc ... 0x54e2:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x54e3 ... 0x5635:
			out_ctx.rsp = ctx.rsp + (1680);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5636 ... 0x5636:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5637 ... 0x5637:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5638 ... 0x5639:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x563a ... 0x563b:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x563c ... 0x563d:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x563e ... 0x563f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5640 ... 0x5640:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5641 ... 0x56b4:
			out_ctx.rsp = ctx.rsp + (1680);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x56b5 ... 0x56cb:
			out_ctx.rsp = ctx.rsp + (1688);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x56cc ... 0x56cc:
			out_ctx.rsp = ctx.rsp + (1696);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x56cd ... 0x56d3:
			out_ctx.rsp = ctx.rsp + (1704);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x56d4 ... 0x56e2:
			out_ctx.rsp = ctx.rsp + (1712);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x56e3 ... 0x572f:
			out_ctx.rsp = ctx.rsp + (1680);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5730 ... 0x5731:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5732 ... 0x5733:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5734 ... 0x5737:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5738 ... 0x5738:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5739 ... 0x5747:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5748 ... 0x5791:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5792 ... 0x5792:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5793 ... 0x5793:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5794 ... 0x5795:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5796 ... 0x5797:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5798 ... 0x583f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5840 ... 0x5840:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5841 ... 0x5841:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5842 ... 0x5857:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5858 ... 0x589b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x589c ... 0x589c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x589d ... 0x589d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x589e ... 0x589f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x58a0 ... 0x58bf:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x58c0 ... 0x58c1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x58c2 ... 0x58c3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x58c4 ... 0x58c5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x58c6 ... 0x58c9:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x58ca ... 0x58ca:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x58cb ... 0x5947:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5948 ... 0x5948:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5949 ... 0x594a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x594b ... 0x594c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x594d ... 0x594e:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x594f ... 0x594f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5950 ... 0x599f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x59a0 ... 0x59a0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x59a1 ... 0x5aad:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x5aae ... 0x5aaf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x5ab0 ... 0x5b3f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x5b40 ... 0x5b40:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5b41 ... 0x5b41:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5b42 ... 0x5b4b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5b4c ... 0x5b5b:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5b5c ... 0x5b62:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5b63 ... 0x5b63:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5b64 ... 0x5c1f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5c20 ... 0x5c21:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5c22 ... 0x5c23:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5c24 ... 0x5c28:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5c29 ... 0x5c2a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5c2b ... 0x5c2f:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5c30 ... 0x5c30:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5c31 ... 0x5c34:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5c35 ... 0x5ce2:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ce3 ... 0x5ce3:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ce4 ... 0x5ce4:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ce5 ... 0x5ce6:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ce7 ... 0x5ce8:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ce9 ... 0x5cea:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ceb ... 0x5cec:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5ced ... 0x5cef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5cf0 ... 0x5daf:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5db0 ... 0x5dba:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5dbb ... 0x5dbe:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5dbf ... 0x5dbf:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5dc0 ... 0x5e3d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5e3e ... 0x5e3e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5e3f ... 0x5e40:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5e41 ... 0x5e47:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5e48 ... 0x5e57:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5e58 ... 0x5e5f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5e60 ... 0x5e7f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5e80 ... 0x5e81:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5e82 ... 0x5e82:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5e83 ... 0x5e83:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5e84 ... 0x5f28:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f29 ... 0x5f29:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f2a ... 0x5f2b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f2c ... 0x5f2c:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f2d ... 0x5f3c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f3d ... 0x5f3d:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f3e ... 0x5f3f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f40 ... 0x5f4f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f50 ... 0x5f50:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x5f51 ... 0x5f51:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x5f52 ... 0x5f57:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5f58 ... 0x5fd2:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5fd3 ... 0x5fd3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5fd4 ... 0x5fd4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5fd5 ... 0x5fdf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x5fe0 ... 0x600f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6010 ... 0x6010:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6011 ... 0x601d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x601e ... 0x6030:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6031 ... 0x6036:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6037 ... 0x603f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6040 ... 0x606f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6070 ... 0x6071:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6072 ... 0x6072:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6073 ... 0x6076:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x6077 ... 0x60b0:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60b1 ... 0x60b1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60b2 ... 0x60b3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60b4 ... 0x60b7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60b8 ... 0x60c2:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60c3 ... 0x60cd:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60ce ... 0x60cf:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x60d0 ... 0x653f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6540 ... 0x6540:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6541 ... 0x6578:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6579 ... 0x657f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6580 ... 0x66cf:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x66d0 ... 0x6719:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x671a ... 0x671a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x671b ... 0x671b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x671c ... 0x676d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x676e ... 0x676e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x676f ... 0x6770:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6771 ... 0x677f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6780 ... 0x6780:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6781 ... 0x6781:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6782 ... 0x6783:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6784 ... 0x6787:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6788 ... 0x679f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x67a0 ... 0x67af:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x67b0 ... 0x67b1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x67b2 ... 0x67b3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x67b4 ... 0x67b5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x67b6 ... 0x67b7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x67b8 ... 0x67b8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x67b9 ... 0x67b9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x67ba ... 0x67c0:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x67c1 ... 0x683e:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x683f ... 0x683f:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6840 ... 0x6840:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6841 ... 0x6842:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6843 ... 0x6844:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6845 ... 0x6846:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6847 ... 0x6848:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6849 ... 0x684f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6850 ... 0x698f:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6990 ... 0x69b2:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x69b3 ... 0x69ce:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x69cf ... 0x69df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x69e0 ... 0x69e7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x69e8 ... 0x69f9:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x69fa ... 0x6a0f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6a10 ... 0x6a4f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x6a50 ... 0x6a50:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6a51 ... 0x6a51:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x6a52 ... 0x6a58:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6a59 ... 0x6b39:
			out_ctx.rsp = ctx.rsp + (176);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6b3a ... 0x6b3a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6b3b ... 0x6b3b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6b3c ... 0x6b3c:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6b3d ... 0x6b4f:
			out_ctx.rsp = ctx.rsp + (176);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6b50 ... 0x6b5c:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6b5d ... 0x6b6e:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6b6f ... 0x6b77:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6b78 ... 0x6b9a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6b9b ... 0x6b9f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6ba0 ... 0x6ba1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6ba2 ... 0x6ba3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6ba4 ... 0x6ba8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6ba9 ... 0x6baa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6bab ... 0x6bae:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x6baf ... 0x6baf:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x6bb0 ... 0x6bb5:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6bb6 ... 0x6d2f:
			out_ctx.rsp = ctx.rsp + (160);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d30 ... 0x6d30:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d31 ... 0x6d31:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d32 ... 0x6d33:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d34 ... 0x6d35:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d36 ... 0x6d37:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d38 ... 0x6d39:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d3a ... 0x6d3f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x6d40 ... 0x702f:
			out_ctx.rsp = ctx.rsp + (160);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7030 ... 0x7031:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7032 ... 0x7033:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7034 ... 0x7038:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7039 ... 0x703a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x703b ... 0x703e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x703f ... 0x703f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x7040 ... 0x704f:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7050 ... 0x7290:
			out_ctx.rsp = ctx.rsp + (8320);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7291 ... 0x7291:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7292 ... 0x7292:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7293 ... 0x7294:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7295 ... 0x7296:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7297 ... 0x7298:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7299 ... 0x729a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x729b ... 0x729f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x72a0 ... 0x743f:
			out_ctx.rsp = ctx.rsp + (8320);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7440 ... 0x7441:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7442 ... 0x7443:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7444 ... 0x7448:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7449 ... 0x744a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x744b ... 0x744e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x744f ... 0x744f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x7450 ... 0x7459:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x745a ... 0x7483:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7484 ... 0x748b:
			out_ctx.rsp = ctx.rsp + (88);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x748c ... 0x74a5:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74a6 ... 0x74a6:
			out_ctx.rsp = ctx.rsp + (88);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74a7 ... 0x74aa:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74ab ... 0x74ae:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74af ... 0x74af:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74b0 ... 0x74b1:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74b2 ... 0x74b3:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74b4 ... 0x74b5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74b6 ... 0x74b7:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74b8 ... 0x74bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x74c0 ... 0x757d:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x757e ... 0x7585:
			out_ctx.rsp = ctx.rsp + (88);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7586 ... 0x75a9:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x75aa ... 0x75aa:
			out_ctx.rsp = ctx.rsp + (88);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x75ab ... 0x789f:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x78a0 ... 0x78a0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x78a1 ... 0x78a1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x78a2 ... 0x78ae:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x78af ... 0x79dc:
			out_ctx.rsp = ctx.rsp + (704);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x79dd ... 0x79dd:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x79de ... 0x79de:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x79df ... 0x79df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x79e0 ... 0x7a3f:
			out_ctx.rsp = ctx.rsp + (704);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7a40 ... 0x7a41:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7a42 ... 0x7a43:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7a44 ... 0x7a45:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7a46 ... 0x7a47:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7a48 ... 0x7a48:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x7a49 ... 0x7a49:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x7a4a ... 0x7a53:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7a54 ... 0x7bf9:
			out_ctx.rsp = ctx.rsp + (4960);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7bfa ... 0x7c04:
			out_ctx.rsp = ctx.rsp + (4968);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7c05 ... 0x7c37:
			out_ctx.rsp = ctx.rsp + (4976);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7c38 ... 0x7c39:
			out_ctx.rsp = ctx.rsp + (4968);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7c3a ... 0x7e27:
			out_ctx.rsp = ctx.rsp + (4960);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e28 ... 0x7e28:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e29 ... 0x7e29:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e2a ... 0x7e2b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e2c ... 0x7e2d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e2e ... 0x7e2f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e30 ... 0x7e31:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e32 ... 0x7e37:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x7e38 ... 0x82ff:
			out_ctx.rsp = ctx.rsp + (4960);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8300 ... 0x830c:
			out_ctx.rsp = ctx.rsp + (4968);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x830d ... 0x8335:
			out_ctx.rsp = ctx.rsp + (4976);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8336 ... 0x8336:
			out_ctx.rsp = ctx.rsp + (4968);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8337 ... 0x848f:
			out_ctx.rsp = ctx.rsp + (4960);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8490 ... 0x8490:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8491 ... 0x8491:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x8492 ... 0x84a3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x84a4 ... 0x850d:
			out_ctx.rsp = ctx.rsp + (8272);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x850e ... 0x850e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x850f ... 0x850f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8510 ... 0x8510:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8511 ... 0x851f:
			out_ctx.rsp = ctx.rsp + (8272);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8520 ... 0x8520:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8521 ... 0x8521:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x8522 ... 0x852b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x852c ... 0x85ef:
			out_ctx.rsp = ctx.rsp + (704);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x85f0 ... 0x85f0:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x85f1 ... 0x85f1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x85f2 ... 0x85f7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x85f8 ... 0x86cf:
			out_ctx.rsp = ctx.rsp + (704);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x86d0 ... 0x86df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x86e0 ... 0x86e1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x86e2 ... 0x86e3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x86e4 ... 0x86e4:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x86e5 ... 0x86eb:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x86ec ... 0x8987:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8988 ... 0x8988:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8989 ... 0x898a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x898b ... 0x898c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x898d ... 0x898e:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x898f ... 0x898f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8990 ... 0x89ef:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x89f0 ... 0x89f1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x89f2 ... 0x89f3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x89f4 ... 0x89f5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x89f6 ... 0x89f7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x89f8 ... 0x89f8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x89f9 ... 0x89f9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x89fa ... 0x89fd:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x89fe ... 0x8b27:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b28 ... 0x8b28:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b29 ... 0x8b29:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b2a ... 0x8b2b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b2c ... 0x8b2d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b2e ... 0x8b2f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b30 ... 0x8b31:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b32 ... 0x8b37:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b38 ... 0x8b83:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b84 ... 0x8b89:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b8a ... 0x8b8a:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b8b ... 0x8b8c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b8d ... 0x8b8e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b8f ... 0x8b90:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b91 ... 0x8b92:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8b93 ... 0x8b9f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8ba0 ... 0x8bae:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8baf ... 0x8bb0:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8bb1 ... 0x8bb9:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8bba ... 0x8bbb:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8bbc ... 0x8bbc:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8bbd ... 0x8bbd:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x8bbe ... 0x8bc1:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8bc2 ... 0x8cd8:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8cd9 ... 0x8cd9:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8cda ... 0x8cda:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x8cdb ... 0x8cdc:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8cdd ... 0x8cde:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8cdf ... 0x8ce0:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8ce1 ... 0x8ce2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8ce3 ... 0x8cef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8cf0 ... 0x8d42:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d43 ... 0x8d43:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d44 ... 0x8d44:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d45 ... 0x8d46:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d47 ... 0x8d48:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d49 ... 0x8d4a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d4b ... 0x8d4c:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d4d ... 0x8d4f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8d50 ... 0x8e6b:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e6c ... 0x8e6c:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e6d ... 0x8e6d:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e6e ... 0x8e6f:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e70 ... 0x8e71:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e72 ... 0x8e73:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e74 ... 0x8e75:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e76 ... 0x8e7f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8e80 ... 0x8ef7:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8ef8 ... 0x8eff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8f00 ... 0x8f66:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8f67 ... 0x8f6c:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x8f6d ... 0x8f6d:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x8f6e ... 0x8f6f:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8f70 ... 0x8f71:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8f72 ... 0x8f73:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8f74 ... 0x8f75:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x8f76 ... 0x908f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x9090 ... 0x9098:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x9099 ... 0x9099:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x909a ... 0x909a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x909b ... 0x90da:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x90db ... 0x90ed:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x90ee ... 0x915a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x915b ... 0x915f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x9160 ... 0x9160:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x9161 ... 0x9161:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x9162 ... 0x9167:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x9168 ... 0x91f2:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x91f3 ... 0x91f3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x91f4 ... 0x91f4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x91f5 ... 0x91ff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x9200 ... 0x922f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x9230 ... 0x9230:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x9231 ... 0x9233:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x9234 ... 0x923b:
			out_ctx.rsp = ctx.rbp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x923c ... 0x924c:
			out_ctx.rsp = ctx.rbp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x924d ... 0x955b:
			out_ctx.rsp = ctx.rbp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x955c ... 0x955f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x9560 ... 0xa08f:
			out_ctx.rsp = ctx.rbp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa090 ... 0xa091:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa092 ... 0xa093:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa094 ... 0xa098:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa099 ... 0xa09a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa09b ... 0xa09b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa09c ... 0xa09c:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xa09d ... 0xa0a6:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa0a7 ... 0xa164:
			out_ctx.rsp = ctx.rsp + (896);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa165 ... 0xa165:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa166 ... 0xa166:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa167 ... 0xa168:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa169 ... 0xa16a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa16b ... 0xa16c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa16d ... 0xa16e:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa16f ... 0xa16f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa170 ... 0xa39c:
			out_ctx.rsp = ctx.rsp + (896);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa39d ... 0xa3a3:
			out_ctx.rsp = ctx.rsp + (904);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa3a4 ... 0xa3da:
			out_ctx.rsp = ctx.rsp + (912);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa3db ... 0xa3e3:
			out_ctx.rsp = ctx.rsp + (904);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa3e4 ... 0xa90f:
			out_ctx.rsp = ctx.rsp + (896);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa910 ... 0xa911:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa912 ... 0xa915:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa916 ... 0xa919:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xa91a ... 0xa95f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa960 ... 0xa968:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa969 ... 0xa96a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa96b ... 0xa96f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa970 ... 0xa970:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa971 ... 0xa971:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa972 ... 0xa973:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa974 ... 0xa97f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa980 ... 0xa981:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa982 ... 0xa985:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xa986 ... 0xa98b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xa98c ... 0xa9ce:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9cf ... 0xa9d7:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9d8 ... 0xa9d9:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9da ... 0xa9df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9e0 ... 0xa9e0:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9e1 ... 0xa9e1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9e2 ... 0xa9e3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xa9e4 ... 0xaeaf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaeb0 ... 0xaeb1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xaeb2 ... 0xaeb2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xaeb3 ... 0xaeb6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xaeb7 ... 0xaf00:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf01 ... 0xaf07:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf08 ... 0xaf09:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf0a ... 0xaf0f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf10 ... 0xaf2c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf2d ... 0xaf2d:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf2e ... 0xaf2f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf30 ... 0xaf3f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf40 ... 0xaf41:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xaf42 ... 0xaf42:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xaf43 ... 0xaf46:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xaf47 ... 0xaf90:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf91 ... 0xaf97:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf98 ... 0xaf99:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xaf9a ... 0xaf9f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xafa0 ... 0xafbc:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xafbd ... 0xafbd:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xafbe ... 0xafbf:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xafc0 ... 0xafcf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xafd0 ... 0xb011:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb012 ... 0xb012:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb013 ... 0xb016:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb017 ... 0xb065:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb066 ... 0xb066:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb067 ... 0xb068:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb069 ... 0xb06f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb070 ... 0xb070:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb071 ... 0xb071:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb072 ... 0xb073:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb074 ... 0xb077:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb078 ... 0xb07f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb080 ... 0xb0c1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb0c2 ... 0xb0c2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb0c3 ... 0xb0c6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb0c7 ... 0xb115:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb116 ... 0xb116:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb117 ... 0xb118:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb119 ... 0xb11f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb120 ... 0xb120:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb121 ... 0xb121:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb122 ... 0xb123:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb124 ... 0xb127:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb128 ... 0xb2bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb2c0 ... 0xb309:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb30a ... 0xb30a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb30b ... 0xb30b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb30c ... 0xb35d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb35e ... 0xb35e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb35f ... 0xb360:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb361 ... 0xb36f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb370 ... 0xb370:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb371 ... 0xb371:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb372 ... 0xb373:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb374 ... 0xb377:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb378 ... 0xb38f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb390 ... 0xb39f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb3a0 ... 0xb3a1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb3a2 ... 0xb3a2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xb3a3 ... 0xb3a6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xb3a7 ... 0xb3af:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xb3b0 ... 0xbb2f:
			out_ctx.rsp = ctx.rsp + (160);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbb30 ... 0xbb31:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbb32 ... 0xbb33:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbb34 ... 0xbb3a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbb3b ... 0xbb3c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbb3d ... 0xbb40:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbb41 ... 0xbb41:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbb42 ... 0xbb5d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbb5e ... 0xbbe1:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbe2 ... 0xbbe5:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbe6 ... 0xbbe6:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbe7 ... 0xbbe8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbe9 ... 0xbbea:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbeb ... 0xbbec:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbed ... 0xbbee:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbef ... 0xbbef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbbf0 ... 0xbc1f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbc20 ... 0xbc21:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbc22 ... 0xbc23:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbc24 ... 0xbc28:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbc29 ... 0xbc2a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbc2b ... 0xbc2e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbc2f ... 0xbc2f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbc30 ... 0xbc36:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbc37 ... 0xbd1c:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd1d ... 0xbd1d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd1e ... 0xbd1e:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd1f ... 0xbd20:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd21 ... 0xbd22:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd23 ... 0xbd24:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd25 ... 0xbd26:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd27 ... 0xbd2f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd30 ... 0xbd4f:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbd50 ... 0xbd55:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbd56 ... 0xbd5b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbd5c ... 0xbd5f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbd60 ... 0xbda1:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbda2 ... 0xbda2:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbda3 ... 0xbda4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbda5 ... 0xbdb7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbdb8 ... 0xbdcf:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbdd0 ... 0xbdd1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbdd2 ... 0xbdd3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbdd4 ... 0xbdd8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbdd9 ... 0xbdda:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbddb ... 0xbddd:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbdde ... 0xbdde:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbddf ... 0xbdf4:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbdf5 ... 0xbed7:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbed8 ... 0xbed8:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbed9 ... 0xbed9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbeda ... 0xbedb:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbedc ... 0xbedd:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbede ... 0xbedf:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbee0 ... 0xbee1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbee2 ... 0xbee7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbee8 ... 0xbeeb:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbeec ... 0xbef1:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbef2 ... 0xbef2:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbef3 ... 0xbef4:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbef5 ... 0xbef6:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbef7 ... 0xbef8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbef9 ... 0xbefa:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbefb ... 0xbf0f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf10 ... 0xbf11:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf12 ... 0xbf13:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf14 ... 0xbf18:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf19 ... 0xbf1a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf1b ... 0xbf1e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf1f ... 0xbf1f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbf20 ... 0xbf2f:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf30 ... 0xbf49:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf4a ... 0xbf4a:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf4b ... 0xbf4b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf4c ... 0xbf4d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf4e ... 0xbf4f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf50 ... 0xbf51:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf52 ... 0xbf53:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf54 ... 0xbf54:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf55 ... 0xbf7f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbf80 ... 0xbf81:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf82 ... 0xbf83:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf84 ... 0xbf85:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf86 ... 0xbf86:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbf87 ... 0xbf87:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbf88 ... 0xbfc2:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfc3 ... 0xbfc6:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfc7 ... 0xbfc8:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfc9 ... 0xbfca:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfcb ... 0xbfcc:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfcd ... 0xbfcf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfd0 ... 0xbfd1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbfd2 ... 0xbfd3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbfd4 ... 0xbfd5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbfd6 ... 0xbfd7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbfd8 ... 0xbfd8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xbfd9 ... 0xbfd9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xbfda ... 0xbfe0:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xbfe1 ... 0xc218:
			out_ctx.rsp = ctx.rsp + (288);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc219 ... 0xc219:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc21a ... 0xc21a:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc21b ... 0xc21c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc21d ... 0xc21e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc21f ... 0xc220:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc221 ... 0xc222:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc223 ... 0xc227:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc228 ... 0xc64f:
			out_ctx.rsp = ctx.rsp + (288);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc650 ... 0xc650:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc651 ... 0xc651:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xc652 ... 0xc655:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc656 ... 0xc692:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc693 ... 0xc693:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc694 ... 0xc694:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc695 ... 0xc695:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc696 ... 0xc6ff:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc700 ... 0xc700:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc701 ... 0xc701:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xc702 ... 0xc70a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc70b ... 0xc746:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc747 ... 0xc74a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc74b ... 0xc74b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc74c ... 0xc74f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc750 ... 0xc753:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc754 ... 0xc75a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc75b ... 0xc75b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc75c ... 0xc75f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc760 ... 0xc760:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc761 ... 0xc761:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xc762 ... 0xc768:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc769 ... 0xc7ab:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc7ac ... 0xc7af:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc7b0 ... 0xc7b0:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc7b1 ... 0xc7b7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc7b8 ... 0xc82f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc830 ... 0xc830:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc831 ... 0xc84b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xc84c ... 0xc84f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xc850 ... 0xc86c:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xc86d ... 0xc86f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xc870 ... 0xc875:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xc876 ... 0xc87f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xc880 ... 0xc88f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc890 ... 0xc890:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xc891 ... 0xc89e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc89f ... 0xc8bb:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc8bc ... 0xc8bc:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc8bd ... 0xc8bd:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc8be ... 0xc8bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc8c0 ... 0xc8c7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc8c8 ... 0xc91f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc920 ... 0xc920:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc921 ... 0xc921:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc922 ... 0xc927:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc928 ... 0xc93f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc940 ... 0xc946:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc947 ... 0xc948:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc949 ... 0xc94c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc94d ... 0xc94d:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xc94e ... 0xc95c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc95d ... 0xc99b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc99c ... 0xc99f:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9a0 ... 0xc9a0:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xc9a1 ... 0xc9a2:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc9a3 ... 0xc9a4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc9a5 ... 0xc9af:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc9b0 ... 0xc9b3:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9b4 ... 0xc9b4:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9b5 ... 0xc9b5:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9b6 ... 0xc9b7:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9b8 ... 0xc9b9:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9ba ... 0xc9bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9c0 ... 0xc9c1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc9c2 ... 0xc9cf:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xc9d0 ... 0xc9d3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xc9d4 ... 0xca20:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xca21 ... 0xca21:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xca22 ... 0xcbcf:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbd0 ... 0xcbd3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbd4 ... 0xcbe2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbe3 ... 0xcbe3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbe4 ... 0xcbef:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbf0 ... 0xcbf1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbf2 ... 0xcbf3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbf4 ... 0xcbf8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbf9 ... 0xcbfa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbfb ... 0xcbfe:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcbff ... 0xcbff:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xcc00 ... 0xcc06:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xcc07 ... 0xcca7:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xcca8 ... 0xccab:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccac ... 0xccac:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccad ... 0xccae:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccaf ... 0xccb0:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccb1 ... 0xccb2:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccb3 ... 0xccb4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccb5 ... 0xccbf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xccc0 ... 0xcdaf:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xcdb0 ... 0xcdb1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcdb2 ... 0xcdb3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcdb4 ... 0xcdb5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcdb6 ... 0xcdb7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcdb8 ... 0xcdb8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xcdb9 ... 0xcdb9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xcdba ... 0xcdc3:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xcdc4 ... 0xd022:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd023 ... 0xd023:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd024 ... 0xd024:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd025 ... 0xd026:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd027 ... 0xd028:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd029 ... 0xd02a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd02b ... 0xd02c:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd02d ... 0xd02f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd030 ... 0xd1cf:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd1d0 ... 0xd1d0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd1d1 ... 0xd1dc:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd1dd ... 0xd229:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd22a ... 0xd22a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd22b ... 0xd22b:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd22c ... 0xd23f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd240 ... 0xd243:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd244 ... 0xd27b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd27c ... 0xd27f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd280 ... 0xd297:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd298 ... 0xd35f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd360 ... 0xd360:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd361 ... 0xd37b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd37c ... 0xd37c:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd37d ... 0xd38f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xd390 ... 0xd391:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd392 ... 0xd393:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd394 ... 0xd398:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd399 ... 0xd399:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd39a ... 0xd39d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xd39e ... 0xd43e:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd43f ... 0xd442:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd443 ... 0xd444:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd445 ... 0xd446:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd447 ... 0xd448:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd449 ... 0xd44f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd450 ... 0xd480:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd481 ... 0xd481:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd482 ... 0xd483:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd484 ... 0xd485:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd486 ... 0xd487:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd488 ... 0xd48f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd490 ... 0xd4a2:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd4a3 ... 0xd4a6:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd4a7 ... 0xd4a8:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd4a9 ... 0xd4aa:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd4ab ... 0xd4ac:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd4ad ... 0xd52f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd530 ... 0xd531:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd532 ... 0xd533:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd534 ... 0xd535:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd536 ... 0xd537:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd538 ... 0xd538:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd539 ... 0xd539:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xd53a ... 0xd53d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd53e ... 0xd62b:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd62c ... 0xd631:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd632 ... 0xd632:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd633 ... 0xd634:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd635 ... 0xd636:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd637 ... 0xd638:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd639 ... 0xd63a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd63b ... 0xd63f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd640 ... 0xd663:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd664 ... 0xd666:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd667 ... 0xd667:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd668 ... 0xd669:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd66a ... 0xd66b:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd66c ... 0xd66d:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd66e ... 0xd66f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd670 ... 0xd75f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd760 ... 0xd761:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd762 ... 0xd763:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd764 ... 0xd767:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd768 ... 0xd768:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xd769 ... 0xd76e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd76f ... 0xd83e:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd83f ... 0xd845:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd846 ... 0xd846:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd847 ... 0xd848:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd849 ... 0xd84a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd84b ... 0xd85f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd860 ... 0xd8af:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd8b0 ... 0xd8b1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd8b2 ... 0xd8b2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd8b3 ... 0xd8b6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xd8b7 ... 0xd8ef:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd8f0 ... 0xd8f3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd8f4 ... 0xd8f5:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd8f6 ... 0xd8ff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd900 ... 0xd903:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd904 ... 0xd904:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd905 ... 0xd909:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd90a ... 0xd90f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd910 ... 0xd94b:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd94c ... 0xd95f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd960 ... 0xd960:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xd961 ... 0xd961:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xd962 ... 0xd96b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd96c ... 0xd9be:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9bf ... 0xd9bf:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9c0 ... 0xd9c0:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9c1 ... 0xd9c7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9c8 ... 0xd9ce:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9cf ... 0xd9cf:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9d0 ... 0xd9d0:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xd9d1 ... 0xda4f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xda50 ... 0xda51:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xda52 ... 0xda53:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xda54 ... 0xda55:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xda56 ... 0xda57:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xda58 ... 0xda58:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xda59 ... 0xda59:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xda5a ... 0xda5d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xda5e ... 0xdaa7:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdaa8 ... 0xdaab:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdaac ... 0xdaac:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdaad ... 0xdaae:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdaaf ... 0xdab0:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdab1 ... 0xdab2:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdab3 ... 0xdab4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdab5 ... 0xdab5:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdab6 ... 0xdb1f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdb20 ... 0xdb21:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdb22 ... 0xdb23:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdb24 ... 0xdb2c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdb2d ... 0xdb2e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdb2f ... 0xdb32:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdb33 ... 0xdb33:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xdb34 ... 0xdb43:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdb44 ... 0xdc26:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc27 ... 0xdc2a:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc2b ... 0xdc2b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc2c ... 0xdc2d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc2e ... 0xdc2f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc30 ... 0xdc31:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc32 ... 0xdc33:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc34 ... 0xdc37:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdc38 ... 0xdcef:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdcf0 ... 0xdcf1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdcf2 ... 0xdcf2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdcf3 ... 0xdcf6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xdcf7 ... 0xdd7b:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdd7c ... 0xdd7c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdd7d ... 0xdd7e:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdd7f ... 0xdd7f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xdd80 ... 0xdd81:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdd82 ... 0xdd82:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xdd83 ... 0xdd86:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xdd87 ... 0xde4c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xde4d ... 0xde50:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xde51 ... 0xde52:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xde53 ... 0xde5f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xde60 ... 0xde61:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xde62 ... 0xde62:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xde63 ... 0xde66:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xde67 ... 0xde6a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xde6b ... 0xe003:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe004 ... 0xe004:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe005 ... 0xe005:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe006 ... 0xe007:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe008 ... 0xe00f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe010 ... 0xe0af:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe0b0 ... 0xe0b1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe0b2 ... 0xe0b3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe0b4 ... 0xe0b4:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe0b5 ... 0xe0b5:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xe0b6 ... 0xe0b9:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe0ba ... 0xe113:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe114 ... 0xe114:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe115 ... 0xe115:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe116 ... 0xe117:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe118 ... 0xe119:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe11a ... 0xe11f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe120 ... 0xe33f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe340 ... 0xe340:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe341 ... 0xe347:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe348 ... 0xe383:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe384 ... 0xe384:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe385 ... 0xe38f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe390 ... 0xe39f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe3a0 ... 0xe3a1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe3a2 ... 0xe3a2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe3a3 ... 0xe3a8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xe3a9 ... 0xe3af:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe3b0 ... 0xe3f9:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe3fa ... 0xe3fa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe3fb ... 0xe3fb:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe3fc ... 0xe3fd:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe3fe ... 0xe3ff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe400 ... 0xe5af:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe5b0 ... 0xe5b0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe5b1 ... 0xe5b1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xe5b2 ... 0xe5bb:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe5bc ... 0xe5ce:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe5cf ... 0xe5d2:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe5d3 ... 0xe5d3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe5d4 ... 0xe5ef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe5f0 ... 0xe60d:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe60e ... 0xe61d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe61e ... 0xe61f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe620 ... 0xe63d:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe63e ... 0xe652:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe653 ... 0xe65f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe660 ... 0xe660:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe661 ... 0xe670:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe671 ... 0xe74f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0xe750 ... 0xe751:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe752 ... 0xe753:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe754 ... 0xe757:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe758 ... 0xe759:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe75a ... 0xe75d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xe75e ... 0xe75e:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xe75f ... 0xe772:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe773 ... 0xe8f8:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe8f9 ... 0xe928:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe929 ... 0xe929:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xe92a ... 0xea67:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xea68 ... 0xea9e:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xea9f ... 0xea9f:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeaa0 ... 0xeb88:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb89 ... 0xeb89:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb8a ... 0xeb8a:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb8b ... 0xeb8c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb8d ... 0xeb8e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb8f ... 0xeb90:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb91 ... 0xeb92:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb93 ... 0xeb97:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeb98 ... 0xecc3:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xecc4 ... 0xecd5:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xecd6 ... 0xecd6:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xecd7 ... 0xece3:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xece4 ... 0xecf0:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xecf1 ... 0xecf2:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xecf3 ... 0xee43:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xee44 ... 0xee7c:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xee7d ... 0xee7d:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xee7e ... 0xee9a:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xee9b ... 0xeecd:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeece ... 0xeed2:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeed3 ... 0xeef9:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xeefa ... 0xef05:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xef06 ... 0xef07:
			out_ctx.rsp = ctx.rsp + (216);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xef08 ... 0xf15f:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf160 ... 0xf161:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf162 ... 0xf163:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf164 ... 0xf167:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf168 ... 0xf168:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xf169 ... 0xf172:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf173 ... 0xf1ed:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf1ee ... 0xf1ee:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf1ef ... 0xf1ef:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf1f0 ... 0xf1f1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf1f2 ... 0xf1f3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf1f4 ... 0xf1f7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf1f8 ... 0xf34f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf350 ... 0xf351:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf352 ... 0xf352:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf353 ... 0xf353:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xf354 ... 0xf3de:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf3df ... 0xf3df:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf3e0 ... 0xf3e1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf3e2 ... 0xf3e7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf3e8 ... 0xf3ef:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf3f0 ... 0xf3f1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf3f2 ... 0xf3f2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf3f3 ... 0xf3f6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xf3f7 ... 0xf433:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf434 ... 0xf434:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf435 ... 0xf436:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf437 ... 0xf43f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf440 ... 0xf478:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf479 ... 0xf47b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf47c ... 0xf47d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf47e ... 0xf47f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf480 ... 0xf4ef:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf4f0 ... 0xf4f1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf4f2 ... 0xf4f2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf4f3 ... 0xf4f3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xf4f4 ... 0xf57e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf57f ... 0xf57f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf580 ... 0xf581:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf582 ... 0xf587:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf588 ... 0xf58f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf590 ... 0xf591:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf592 ... 0xf592:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf593 ... 0xf596:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xf597 ... 0xf5d3:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf5d4 ... 0xf5d4:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf5d5 ... 0xf5d6:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf5d7 ... 0xf5df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf5e0 ... 0xf618:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf619 ... 0xf61b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf61c ... 0xf61d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf61e ... 0xf61f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf620 ... 0xf77f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf780 ... 0xf781:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf782 ... 0xf783:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf784 ... 0xf788:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf789 ... 0xf78a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf78b ... 0xf78e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xf78f ... 0xf78f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xf790 ... 0xf799:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf79a ... 0xf8c9:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8ca ... 0xf8cd:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8ce ... 0xf8ce:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8cf ... 0xf8d0:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8d1 ... 0xf8d2:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8d3 ... 0xf8d4:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8d5 ... 0xf8d6:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8d7 ... 0xf8df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xf8e0 ... 0xfb4f:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfb50 ... 0xfb51:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfb52 ... 0xfb53:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfb54 ... 0xfb58:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfb59 ... 0xfb5a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfb5b ... 0xfb5e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfb5f ... 0xfb5f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xfb60 ... 0xfb66:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfb67 ... 0xfbc0:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbc1 ... 0xfbc4:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbc5 ... 0xfbc5:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbc6 ... 0xfbc7:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbc8 ... 0xfbc9:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbca ... 0xfbcb:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbcc ... 0xfbcd:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbce ... 0xfbcf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbd0 ... 0xfbef:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfbf0 ... 0xfbf1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfbf2 ... 0xfbf3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfbf4 ... 0xfbf5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfbf6 ... 0xfbf7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfbf8 ... 0xfbfc:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfbfd ... 0xfbfd:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xfbfe ... 0xfc04:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfc05 ... 0xfd3e:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd3f ... 0xfd3f:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd40 ... 0xfd40:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd41 ... 0xfd42:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd43 ... 0xfd44:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd45 ... 0xfd46:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd47 ... 0xfd48:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd49 ... 0xfd4f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfd50 ... 0xfdcf:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfdd0 ... 0xfdd0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfdd1 ... 0xfdd1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xfdd2 ... 0xfdda:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfddb ... 0xfde4:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfde5 ... 0xfdea:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfdeb ... 0xfdeb:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfdec ... 0xfdff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe00 ... 0xfe01:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfe02 ... 0xfe03:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfe04 ... 0xfe05:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfe06 ... 0xfe07:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfe08 ... 0xfe0b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0xfe0c ... 0xfe0c:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0xfe0d ... 0xfe13:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe14 ... 0xfe43:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe44 ... 0xfe44:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe45 ... 0xfe45:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe46 ... 0xfe47:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe48 ... 0xfe49:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe4a ... 0xfe4b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe4c ... 0xfe4d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe4e ... 0xfe4f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xfe50 ... 0xff27:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff28 ... 0xff28:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff29 ... 0xff2c:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff2d ... 0xff3a:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff3b ... 0xff3c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff3d ... 0xff3e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff3f ... 0xff40:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff41 ... 0xff4f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0xff50 ... 0x1004f:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10050 ... 0x10054:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x10055 ... 0x10055:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x10056 ... 0x10059:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x1005a ... 0x1008c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1008d ... 0x1008d:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1008e ... 0x1008f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10090 ... 0x1009f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x100a0 ... 0x100a4:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x100a5 ... 0x100a5:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x100a6 ... 0x100a9:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x100aa ... 0x100dc:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x100dd ... 0x100dd:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x100de ... 0x100df:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x100e0 ... 0x100ef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x100f0 ... 0x100f1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x100f2 ... 0x100f3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x100f4 ... 0x100f8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x100f9 ... 0x100fa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x100fb ... 0x10102:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x10103 ... 0x10103:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x10104 ... 0x10110:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10111 ... 0x101fb:
			out_ctx.rsp = ctx.rsp + (1296);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x101fc ... 0x101fc:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x101fd ... 0x101fd:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x101fe ... 0x101ff:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10200 ... 0x10201:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10202 ... 0x10203:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10204 ... 0x10205:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10206 ... 0x1020f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10210 ... 0x1065c:
			out_ctx.rsp = ctx.rsp + (1296);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1065d ... 0x10663:
			out_ctx.rsp = ctx.rsp + (1304);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10664 ... 0x10690:
			out_ctx.rsp = ctx.rsp + (1312);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10691 ... 0x10692:
			out_ctx.rsp = ctx.rsp + (1304);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x10693 ... 0x11481:
			out_ctx.rsp = ctx.rsp + (1296);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11482 ... 0x11485:
			out_ctx.rsp = ctx.rsp + (1304);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11486 ... 0x1149f:
			out_ctx.rsp = ctx.rsp + (1312);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x114a0 ... 0x114a1:
			out_ctx.rsp = ctx.rsp + (1304);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x114a2 ... 0x11a0f:
			out_ctx.rsp = ctx.rsp + (1296);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11a10 ... 0x11a13:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a14 ... 0x11a2a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a2b ... 0x11a2c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a2d ... 0x11a3a:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a3b ... 0x11a3b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a3c ... 0x11a4f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a50 ... 0x11a50:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a51 ... 0x11a5f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a60 ... 0x11a63:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11a64 ... 0x11ad6:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x11ad7 ... 0x11ad7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x11ad8 ... 0x11aff:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x11b00 ... 0x11b00:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11b01 ... 0x11b01:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x11b02 ... 0x11b0a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b0b ... 0x11b39:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b3a ... 0x11b3a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b3b ... 0x11b3b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b3c ... 0x11b3f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b40 ... 0x11b89:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b8a ... 0x11b8a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b8b ... 0x11b8b:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b8c ... 0x11b8f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11b90 ... 0x11be3:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11be4 ... 0x11be4:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11be5 ... 0x11be5:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11be6 ... 0x11bef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11bf0 ... 0x11bf1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11bf2 ... 0x11bf3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11bf4 ... 0x11bf8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11bf9 ... 0x11bfa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11bfb ... 0x11bfe:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x11bff ... 0x11bff:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x11c00 ... 0x11c12:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x11c13 ... 0x12793:
			out_ctx.rsp = ctx.rsp + (240);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12794 ... 0x1279d:
			out_ctx.rsp = ctx.rsp + (248);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1279e ... 0x127a1:
			out_ctx.rsp = ctx.rsp + (256);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127a2 ... 0x127a6:
			out_ctx.rsp = ctx.rsp + (264);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127a7 ... 0x127c5:
			out_ctx.rsp = ctx.rsp + (272);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127c6 ... 0x127e9:
			out_ctx.rsp = ctx.rsp + (240);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127ea ... 0x127ea:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127eb ... 0x127eb:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127ec ... 0x127ed:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127ee ... 0x127ef:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127f0 ... 0x127f1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127f2 ... 0x127f3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127f4 ... 0x127f7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x127f8 ... 0x12d90:
			out_ctx.rsp = ctx.rsp + (240);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12d91 ... 0x12d9d:
			out_ctx.rsp = ctx.rsp + (248);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12d9e ... 0x12da1:
			out_ctx.rsp = ctx.rsp + (256);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12da2 ... 0x12da8:
			out_ctx.rsp = ctx.rsp + (264);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12da9 ... 0x12dc3:
			out_ctx.rsp = ctx.rsp + (272);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12dc4 ... 0x12e2f:
			out_ctx.rsp = ctx.rsp + (240);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12e30 ... 0x12e31:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12e32 ... 0x12e33:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12e34 ... 0x12e38:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12e39 ... 0x12e3a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12e3b ... 0x12e3e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12e3f ... 0x12e3f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x12e40 ... 0x12e46:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12e47 ... 0x12ee2:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12ee3 ... 0x12f01:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f02 ... 0x12f07:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f08 ... 0x12f09:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f0a ... 0x12f22:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f23 ... 0x12f64:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f65 ... 0x12f6f:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f70 ... 0x12f72:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f73 ... 0x12f77:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f78 ... 0x12f95:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12f96 ... 0x12fa1:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fa2 ... 0x12fa5:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fa6 ... 0x12fa6:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fa7 ... 0x12fa8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fa9 ... 0x12faa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fab ... 0x12fac:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fad ... 0x12fae:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12faf ... 0x12faf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fb0 ... 0x12fdf:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x12fe0 ... 0x12fe1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12fe2 ... 0x12fe2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x12fe3 ... 0x12fe3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x12fe4 ... 0x13013:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13014 ... 0x13014:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13015 ... 0x13016:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13017 ... 0x130bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x130c0 ... 0x130ea:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x130eb ... 0x130ff:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13100 ... 0x13101:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13102 ... 0x13103:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13104 ... 0x1310c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1310d ... 0x1310e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1310f ... 0x13112:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13113 ... 0x13113:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x13114 ... 0x13120:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13121 ... 0x13140:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13141 ... 0x13147:
			out_ctx.rsp = ctx.rsp + (88);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13148 ... 0x1314d:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1314e ... 0x13151:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13152 ... 0x13169:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1316a ... 0x1316a:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1316b ... 0x1316b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1316c ... 0x1316d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1316e ... 0x1316f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13170 ... 0x13171:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13172 ... 0x13173:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13174 ... 0x1317f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13180 ... 0x13181:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13182 ... 0x13183:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13184 ... 0x1318c:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1318d ... 0x1318e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1318f ... 0x13192:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13193 ... 0x13193:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x13194 ... 0x131a0:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x131a1 ... 0x131c6:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x131c7 ... 0x131d3:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x131d4 ... 0x131d9:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x131da ... 0x131db:
			out_ctx.rsp = ctx.rsp + (136);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x131dc ... 0x131f9:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x131fa ... 0x13210:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13211 ... 0x13213:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13214 ... 0x13216:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13217 ... 0x1322c:
			out_ctx.rsp = ctx.rsp + (136);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1322d ... 0x1323e:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1323f ... 0x13259:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1325a ... 0x1325a:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1325b ... 0x1325b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1325c ... 0x1325d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1325e ... 0x1325f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13260 ... 0x13261:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13262 ... 0x13263:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13264 ... 0x1327f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13280 ... 0x13287:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13288 ... 0x1328f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13290 ... 0x13290:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x13291 ... 0x13307:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13308 ... 0x13312:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13313 ... 0x13314:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13315 ... 0x1338f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13390 ... 0x13393:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13394 ... 0x13412:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13413 ... 0x13413:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13414 ... 0x1341f:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13420 ... 0x13423:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13424 ... 0x1349e:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1349f ... 0x1349f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x134a0 ... 0x134cf:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x134d0 ... 0x134d3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x134d4 ... 0x13561:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13562 ... 0x13562:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13563 ... 0x135af:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x135b0 ... 0x135b3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x135b4 ... 0x13632:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13633 ... 0x13633:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13634 ... 0x1363f:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13640 ... 0x13643:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13644 ... 0x136c5:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x136c6 ... 0x136c6:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x136c7 ... 0x1379f:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x137a0 ... 0x137a1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x137a2 ... 0x137a3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x137a4 ... 0x137a5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x137a6 ... 0x137a7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x137a8 ... 0x137ab:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x137ac ... 0x137ac:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x137ad ... 0x137b8:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x137b9 ... 0x1381a:
			out_ctx.rsp = ctx.rsp + (368);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1381b ... 0x1381b:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1381c ... 0x1381c:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1381d ... 0x1381e:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1381f ... 0x13820:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13821 ... 0x13822:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13823 ... 0x13824:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13825 ... 0x1382f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13830 ... 0x1391f:
			out_ctx.rsp = ctx.rsp + (368);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13920 ... 0x13921:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13922 ... 0x13923:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13924 ... 0x13925:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13926 ... 0x13927:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13928 ... 0x1392b:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1392c ... 0x1392c:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x1392d ... 0x13936:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13937 ... 0x13a34:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a35 ... 0x13a4b:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a4c ... 0x13a4d:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a4e ... 0x13a4f:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a50 ... 0x13a51:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a52 ... 0x13a53:
			out_ctx.rsp = ctx.rsp + (136);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a54 ... 0x13a67:
			out_ctx.rsp = ctx.rsp + (144);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a68 ... 0x13a6b:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a6c ... 0x13a6c:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a6d ... 0x13a6d:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a6e ... 0x13a6f:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a70 ... 0x13a71:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a72 ... 0x13a73:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a74 ... 0x13a75:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a76 ... 0x13a7f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13a80 ... 0x13ad0:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ad1 ... 0x13adf:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ae0 ... 0x13afa:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13afb ... 0x13b01:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b02 ... 0x13b02:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b03 ... 0x13b04:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b05 ... 0x13b06:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b07 ... 0x13b08:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b09 ... 0x13b0a:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b0b ... 0x13b1f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b20 ... 0x13b3e:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b3f ... 0x13b50:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b51 ... 0x13b51:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b52 ... 0x13b53:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b54 ... 0x13b55:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b56 ... 0x13b57:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b58 ... 0x13b59:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b5a ... 0x13b67:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b68 ... 0x13b8a:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b8b ... 0x13b9a:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b9b ... 0x13b9b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b9c ... 0x13b9d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13b9e ... 0x13b9f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ba0 ... 0x13ba1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ba2 ... 0x13ba3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ba4 ... 0x13bb7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13bb8 ... 0x13bde:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13bdf ... 0x13be0:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13be1 ... 0x13bfd:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13bfe ... 0x13bfe:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13bff ... 0x13c02:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c03 ... 0x13c03:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c04 ... 0x13c04:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c05 ... 0x13c06:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c07 ... 0x13c08:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c09 ... 0x13c0a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c0b ... 0x13c0c:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c0d ... 0x13c0f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c10 ... 0x13c38:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c39 ... 0x13c3f:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c40 ... 0x13c72:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c73 ... 0x13c77:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c78 ... 0x13c79:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c7a ... 0x13c7b:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c7c ... 0x13c9a:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c9b ... 0x13c9e:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13c9f ... 0x13c9f:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ca0 ... 0x13ca0:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ca1 ... 0x13ca2:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ca3 ... 0x13ca4:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ca5 ... 0x13ca6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ca7 ... 0x13ca8:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ca9 ... 0x13caf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13cb0 ... 0x13ce9:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13cea ... 0x13ceb:
			out_ctx.rsp = ctx.rsp + (104);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13cec ... 0x13ced:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13cee ... 0x13cef:
			out_ctx.rsp = ctx.rsp + (120);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13cf0 ... 0x13cff:
			out_ctx.rsp = ctx.rsp + (128);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13d00 ... 0x13d6f:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13d70 ... 0x13d73:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13d74 ... 0x13dd3:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13dd4 ... 0x13dd4:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13dd5 ... 0x13def:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13df0 ... 0x13df0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13df1 ... 0x13df1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x13df2 ... 0x13e01:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13e02 ... 0x13eac:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ead ... 0x13ead:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13eae ... 0x13eae:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13eaf ... 0x13eaf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13eb0 ... 0x13ecf:
			out_ctx.rsp = ctx.rsp + (208);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x13ed0 ... 0x13ed0:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13ed1 ... 0x13f4f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13f50 ... 0x13f5f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13f60 ... 0x13f60:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13f61 ... 0x13f74:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13f75 ... 0x13f75:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13f76 ... 0x13f7f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13f80 ... 0x13f9e:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13f9f ... 0x13fbf:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13fc0 ... 0x13fc3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x13fc4 ... 0x13fe1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13fe2 ... 0x13fe7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13fe8 ... 0x13ff0:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13ff1 ... 0x13ff1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x13ff2 ... 0x13fff:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x14000 ... 0x1401e:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1401f ... 0x1402f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14030 ... 0x1408e:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1408f ... 0x14097:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14098 ... 0x140bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x140c0 ... 0x14104:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14105 ... 0x1410f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14110 ... 0x14110:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14111 ... 0x14121:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x14122 ... 0x1412f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x14130 ... 0x14136:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14137 ... 0x14158:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14159 ... 0x14159:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1415a ... 0x1415f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14160 ... 0x14160:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14161 ... 0x14161:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14162 ... 0x1416e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1416f ... 0x14177:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14178 ... 0x1417e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1417f ... 0x1417f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14180 ... 0x1418f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14190 ... 0x14190:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14191 ... 0x141a1:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x141a2 ... 0x141af:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x141b0 ... 0x141b3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141b4 ... 0x141ef:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141f0 ... 0x141f1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141f2 ... 0x141f3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141f4 ... 0x141f8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141f9 ... 0x141fa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141fb ... 0x141fe:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x141ff ... 0x141ff:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14200 ... 0x1420d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1420e ... 0x142ae:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142af ... 0x142af:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142b0 ... 0x142b0:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142b1 ... 0x142b2:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142b3 ... 0x142b4:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142b5 ... 0x142b6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142b7 ... 0x142b8:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142b9 ... 0x142bf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x142c0 ... 0x142ff:
			out_ctx.rsp = ctx.rsp + (80);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14300 ... 0x14303:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14304 ... 0x14305:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14306 ... 0x1431f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14320 ... 0x1432f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14330 ... 0x14330:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14331 ... 0x14346:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x14347 ... 0x1434f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x14350 ... 0x1436f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x14370 ... 0x14371:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14372 ... 0x14373:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14374 ... 0x1437f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14380 ... 0x14380:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14381 ... 0x14381:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14382 ... 0x14387:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14388 ... 0x14400:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14401 ... 0x14401:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14402 ... 0x14402:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14403 ... 0x14404:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14405 ... 0x14406:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14407 ... 0x14408:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14409 ... 0x1440f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14410 ... 0x1444f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14450 ... 0x14451:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14452 ... 0x14453:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14454 ... 0x14455:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14456 ... 0x14457:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14458 ... 0x14458:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14459 ... 0x14459:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x1445a ... 0x1445d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1445e ... 0x14546:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14547 ... 0x14547:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14548 ... 0x14548:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14549 ... 0x1454a:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1454b ... 0x1454c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1454d ... 0x1454e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1454f ... 0x14550:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14551 ... 0x14557:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14558 ... 0x1486f:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14870 ... 0x14871:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14872 ... 0x14873:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14874 ... 0x14877:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14878 ... 0x14878:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14879 ... 0x1487f:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14880 ... 0x1491f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14920 ... 0x14921:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14922 ... 0x14923:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14924 ... 0x14925:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14926 ... 0x14927:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14928 ... 0x14928:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14929 ... 0x14929:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x1492a ... 0x1492d:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1492e ... 0x14a16:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a17 ... 0x14a17:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a18 ... 0x14a18:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a19 ... 0x14a1a:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a1b ... 0x14a1c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a1d ... 0x14a1e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a1f ... 0x14a20:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a21 ... 0x14a27:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14a28 ... 0x14d3f:
			out_ctx.rsp = ctx.rsp + (96);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14d40 ... 0x14d41:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14d42 ... 0x14d43:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14d44 ... 0x14d47:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14d48 ... 0x14d48:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14d49 ... 0x14d52:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14d53 ... 0x14db6:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14db7 ... 0x14db7:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14db8 ... 0x14db8:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14db9 ... 0x14dba:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14dbb ... 0x14dbc:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14dbd ... 0x14dbd:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14dbe ... 0x14dcf:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14dd0 ... 0x14dd3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14dd4 ... 0x14e5f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14e60 ... 0x14e64:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14e65 ... 0x14e65:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14e66 ... 0x14e66:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14e67 ... 0x14ec8:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ec9 ... 0x14ec9:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14eca ... 0x14ecb:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ecc ... 0x14ecf:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ed0 ... 0x14f2f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14f30 ... 0x14f31:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14f32 ... 0x14f33:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14f34 ... 0x14f37:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14f38 ... 0x14f38:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x14f39 ... 0x14f39:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x14f3a ... 0x14ff7:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ff8 ... 0x14ff8:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ff9 ... 0x14ffa:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ffb ... 0x14ffc:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14ffd ... 0x14ffe:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x14fff ... 0x14fff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15000 ... 0x1505f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15060 ... 0x15061:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15062 ... 0x15062:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15063 ... 0x15066:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15067 ... 0x150a2:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150a3 ... 0x150a3:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150a4 ... 0x150a5:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150a6 ... 0x150af:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150b0 ... 0x150c0:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150c1 ... 0x150c1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150c2 ... 0x150c3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150c4 ... 0x150c4:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x150c5 ... 0x1512f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15130 ... 0x15135:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15136 ... 0x15151:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x15152 ... 0x15157:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x15158 ... 0x1515f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15160 ... 0x15161:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15162 ... 0x15163:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15164 ... 0x15164:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15165 ... 0x15165:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15166 ... 0x1516c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1516d ... 0x151a2:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151a3 ... 0x151a6:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151a7 ... 0x151a7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151a8 ... 0x151a9:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151aa ... 0x151ab:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151ac ... 0x151af:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151b0 ... 0x151bf:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x151c0 ... 0x151c4:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x151c5 ... 0x151c5:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x151c6 ... 0x151c6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x151c7 ... 0x15221:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15222 ... 0x15222:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15223 ... 0x15224:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15225 ... 0x1522f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15230 ... 0x15253:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15254 ... 0x15254:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15255 ... 0x15256:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15257 ... 0x1525f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15260 ... 0x15261:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15262 ... 0x15263:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15264 ... 0x1526a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1526b ... 0x1526c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1526d ... 0x1526d:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x1526e ... 0x1526e:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x1526f ... 0x15272:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15273 ... 0x15313:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15314 ... 0x15314:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15315 ... 0x15315:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15316 ... 0x15317:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15318 ... 0x15319:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1531a ... 0x1531b:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1531c ... 0x1531d:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1531e ... 0x1531f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15320 ... 0x1539f:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x153a0 ... 0x153a1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x153a2 ... 0x153a2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x153a3 ... 0x153a6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x153a7 ... 0x153b1:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x153b2 ... 0x15420:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15421 ... 0x15424:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15425 ... 0x15425:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15426 ... 0x15427:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15428 ... 0x1542f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15430 ... 0x1544a:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1544b ... 0x1544e:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1544f ... 0x1544f:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15450 ... 0x15451:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15452 ... 0x15457:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15458 ... 0x1546b:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1546c ... 0x1546f:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15470 ... 0x15470:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15471 ... 0x15472:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15473 ... 0x15477:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15478 ... 0x1548f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15490 ... 0x15491:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15492 ... 0x15493:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15494 ... 0x15494:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15495 ... 0x15495:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15496 ... 0x1549c:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1549d ... 0x154de:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x154df ... 0x154e2:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x154e3 ... 0x154e3:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x154e4 ... 0x154e5:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x154e6 ... 0x154e7:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x154e8 ... 0x154ef:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x154f0 ... 0x15501:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15502 ... 0x15504:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15505 ... 0x15505:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15506 ... 0x15507:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15508 ... 0x15509:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1550a ... 0x1550f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15510 ... 0x15513:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15514 ... 0x1551a:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1551b ... 0x1551b:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1551c ... 0x1551d:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1551e ... 0x1551f:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15520 ... 0x15525:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15526 ... 0x1553f:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-40)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15540 ... 0x15541:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15542 ... 0x15542:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15543 ... 0x15543:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15544 ... 0x1554a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1554b ... 0x155d6:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x155d7 ... 0x155d7:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x155d8 ... 0x155d8:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x155d9 ... 0x155da:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x155db ... 0x155df:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x155e0 ... 0x156bf:
			out_ctx.rsp = ctx.rsp + (112);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x156c0 ... 0x156c1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x156c2 ... 0x156c2:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x156c3 ... 0x156c6:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x156c7 ... 0x156f1:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x156f2 ... 0x156f2:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x156f3 ... 0x156f4:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x156f5 ... 0x156ff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15700 ... 0x15715:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15716 ... 0x15716:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15717 ... 0x15718:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15719 ... 0x1571f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15720 ... 0x15720:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15721 ... 0x15726:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15727 ... 0x15728:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15729 ... 0x1572f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15730 ... 0x15739:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1573a ... 0x1573a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1573b ... 0x1573c:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1573d ... 0x1574f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15750 ... 0x15753:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15754 ... 0x15762:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15763 ... 0x15763:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15764 ... 0x157af:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x157b0 ... 0x157b1:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x157b2 ... 0x157b3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x157b4 ... 0x157ba:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x157bb ... 0x157bc:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x157bd ... 0x157bd:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x157be ... 0x157be:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x157bf ... 0x157c5:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x157c6 ... 0x15886:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15887 ... 0x15887:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15888 ... 0x15888:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15889 ... 0x1588a:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1588b ... 0x1588c:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1588d ... 0x1588e:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x1588f ... 0x15890:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15891 ... 0x15897:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15898 ... 0x15c1f:
			out_ctx.rsp = ctx.rsp + (224);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c20 ... 0x15c21:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15c22 ... 0x15c22:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15c23 ... 0x15c23:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15c24 ... 0x15c65:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c66 ... 0x15c66:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c67 ... 0x15c68:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c69 ... 0x15c6f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c70 ... 0x15c91:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c92 ... 0x15c92:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c93 ... 0x15c94:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15c95 ... 0x15c9f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15ca0 ... 0x15caf:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15cb0 ... 0x15cb3:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15cb4 ... 0x15cce:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x15ccf ... 0x15cd7:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x15cd8 ... 0x15ceb:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x15cec ... 0x15cff:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-16)));
			out_ctx.flags = 11u;
			return out_ctx;
		case 0x15d00 ... 0x15d22:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d23 ... 0x15d26:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d27 ... 0x15d2a:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15d2b ... 0x15d54:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15d55 ... 0x15d55:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15d56 ... 0x15d57:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15d58 ... 0x15d5f:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-24)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-32)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15d60 ... 0x15d61:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d62 ... 0x15d63:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d64 ... 0x15d68:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d69 ... 0x15d6a:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d6b ... 0x15d72:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 3u;
			return out_ctx;
		case 0x15d73 ... 0x15d7a:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.flags = 7u;
			return out_ctx;
		case 0x15d7b ... 0x15d87:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15d88 ... 0x15db9:
			out_ctx.rsp = ctx.rsp + (64);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dba ... 0x15dba:
			out_ctx.rsp = ctx.rsp + (56);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dbb ... 0x15dbb:
			out_ctx.rsp = ctx.rsp + (48);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dbc ... 0x15dbd:
			out_ctx.rsp = ctx.rsp + (40);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dbe ... 0x15dbf:
			out_ctx.rsp = ctx.rsp + (32);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dc0 ... 0x15dc1:
			out_ctx.rsp = ctx.rsp + (24);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dc2 ... 0x15dc3:
			out_ctx.rsp = ctx.rsp + (16);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		case 0x15dc4 ... 0x15dc4:
			out_ctx.rsp = ctx.rsp + (8);
			out_ctx.rbp = *((uintptr_t*)(out_ctx.rsp + (-48)));
			out_ctx.rip = *((uintptr_t*)(out_ctx.rsp + (-8)));
			out_ctx.rbx = *((uintptr_t*)(out_ctx.rsp + (-56)));
			out_ctx.flags = 15u;
			return out_ctx;
		default:
			out_ctx.flags = 128u;
			return out_ctx;
		}
}
